"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.engine = exports.render = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const general_utils_1 = require("./utils/general-utils");
const compiler_1 = require("./compiler");
const defaultUserOptions = {
    basePath: '',
    allowRequire: false,
    allowComponents: false,
    filename: '<sandbox>.abell'
};
function render(abellTemplate, 
// eslint-disable-next-line @typescript-eslint/ban-types
userSandbox = {}, options = defaultUserOptions) {
    // Set initial variables
    options.basePath =
        options.basePath ||
            (options.filename && path_1.default.dirname(options.filename)) ||
            '';
    const { builtInFunctions, subComponents } = general_utils_1.getAbellInBuiltSandbox(options);
    const templateSandbox = Object.assign(Object.assign({}, builtInFunctions), userSandbox);
    const html = compiler_1.compile(abellTemplate, templateSandbox, options);
    if (options.allowComponents) {
        return {
            html,
            components: subComponents
        };
    }
    return html;
}
exports.render = render;
function engine({ allowRequire } = { allowRequire: false }) {
    return (filePath, options, callback) => {
        // define the template engine
        const content = fs_1.default.readFileSync(filePath, 'utf-8');
        const rendered = render(content, options, {
            basePath: path_1.default.dirname(filePath),
            allowRequire
        });
        return callback(null, rendered);
    };
}
exports.engine = engine;
exports.default = {
    render,
    engine
};
